FL.objects.Node.Node
====================

.. currentmodule:: FL.objects.Node

.. autoclass:: Node
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Node.Assign
      ~Node.ExpandLayer
      ~Node.Layer
      ~Node.Section
      ~Node.SetAllLayers
      ~Node.Shift
      ~Node.Transform
      ~Node.__init__
      ~Node.fake_deserialize
      ~Node.fake_serialize
      ~Node.fake_update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Node.type
      ~Node.alignment
      ~Node.selected
      ~Node.count
      ~Node.parent
      ~Node.point
      ~Node.points
      ~Node.x
      ~Node.y
   
   